\name{PhenomeImpute}
\alias{PhenomeImpute}
\title{Self-Train Imputation for High dimensional Phenome data}
\usage{
  PhenomeImpute(Data, Type, k, n.re)
}
\arguments{
  \item{Data}{A data matrix with rows being subjects and
  column being variables}

  \item{Type}{vector of variable types in Data. "con" for
  continuous variable; "nom" for nominal
  variables(including binary and multi-level variables);
  "ord" for ordinal variables.}

  \item{k}{Number of neighbors prefered in KNN methods}

  \item{n.re}{Number of second layer missing values being
  generated}
}
\value{
  a list with first element being the imputed dataset; the
  second element being methods selected by each type of
  variables; third element is the unimputable cells within
  the original missing data(represented by row, col and
  variable type of missing value )
}
\description{
  Take in any phenome data with missing values to self
  train best methods for different types of variables.
}
\examples{

## Example 1
## Generate a data matrix with mixed variables
set.seed(1234)
Data = cbind(rnorm(100,0,4),rnorm(100,0,7),rnorm(100,5,4),rnorm(100,-3,4),rnorm(100,0,4),
sample(1:4,100,replace=TRUE),sample(1:2,100,replace=TRUE),sample(1:3,100,replace=TRUE),
sample(1:20,100,replace=TRUE),sample(1:10,100,replace=TRUE))
Data = cbind(Data,Data)
colnames(Data) = paste("var",1:20,sep="")
row.names(Data) = paste("sub",1:100,sep="")
Type = c(rep("con",5),rep("nom",3),rep("ord",2))
Type = c(Type,Type)

for(i in 1:ncol(Data)){
  Data[sample(1:nrow(Data),5),i] = NA
}
Example.1 = PhenomeImpute(Data,Type,5,5)


## Example 2
## Load masked COPD data (a list with first element data matrix and second element variable types)
data(COPD)
set.seed(12345)

for(i in 1:ncol(COPD[[1]])){
COPD[[1]][sample(1:nrow(COPD[[1]]),5),i] = NA
}
Example.2 = PhenomeImpute(COPD[[1]],COPD[[2]],5,2)
## to save time, we set n.re=2. In reality, n.re should be >=5
}
\references{
  MissForest - nonparametric missing value imputation for mixed-type data. Daniel J. Stekhoven, Peter Buhlmann. Bioinformatics 2011, 28:113-118.

  Missing value imputation in high-dimensional phenomic data: Imputable or not? And how? 
  Serena G. Liao1,*, Yan Lin1,*, Dongwan D. Kang, Naftali Kaminski, Frank C. Sciurba, George C. Tseng.
}
