\name{mixedDist}
\alias{mixedDist}
\title{Calculate distance matrix of mixted types of variables}
\usage{
  mixedDist(dat, types)
}
\arguments{
  \item{dat}{A data matrix with rows being subjects and
  column being variables}

  \item{types}{vector of variable types in Data. "con" for
  continuous variable; "nom" for nominal
  variables(including binary and multi-level variables);
  "ord" for ordinal variables.}
}
\value{
  a symmetric distance matrix. (defined as 1 minus absolute pairwise correlation) 
}
\description{
  Calculate distance matrix of mixted types of variables.
}
\examples{

## Example 1
## Generate a data matrix with mixed variables
set.seed(1234)
Data = cbind(rnorm(100,0,4),rnorm(100,0,7),rnorm(100,5,4),rnorm(100,-3,4),rnorm(100,0,4),
sample(1:4,100,replace=TRUE),sample(1:2,100,replace=TRUE),sample(1:3,100,replace=TRUE),
sample(1:20,100,replace=TRUE),sample(1:10,100,replace=TRUE))
Data = cbind(Data,Data)
colnames(Data) = paste("var",1:20,sep="")
row.names(Data) = paste("sub",1:100,sep="")
Type = c(rep("con",5),rep("nom",3),rep("ord",2))
Type = c(Type,Type)

Dist.mat=mixedDist(Data,Type)
}
\references{
  Multivariate correlation models with mixed disrete and continuous variables. Olkin I, Tate RF. The Annals of Mathematical Statistics 1961, 32(2):448-465.

  Measures of Nominal-Ordinal Association. Agresti A. Journal of the American Statistical Association 1981, 76(375):524-529.

  The polyserial correlation coefficient. Ulf Olsson FD, Neil J. Dorans. Psychometrika 1982, 47(3):337-347.

  Maximum likelihood estimation of the polychoric correlation coefficient. Olsson U. Psychometrika 1979, 44(4):443-460.

  Determination of the coefficient of correlation. Science 1909, 29:823-824.

  Mathematical contributions to the theory of evolution. VII. On the correlation of characters not quantitatively measurable. Pearson K. Philos Trans R Soc Lond Ser A Math Phys Eng Sci 1900, 195:1-47.

}
